SF.net SVN: geany: [2259] trunk

eht16 at users.sourceforge.net eht16 at xxxxx
Fri Feb 15 16:32:28 UTC 2008


Revision: 2259
          http://geany.svn.sourceforge.net/geany/?rev=2259&view=rev
Author:   eht16
Date:     2008-02-15 08:32:27 -0800 (Fri, 15 Feb 2008)

Log Message:
-----------
Apply patch from Daniel Richard G. to update some source code comments (thanks).

Modified Paths:
--------------
    trunk/ChangeLog
    trunk/src/socket.c

Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog	2008-02-15 16:31:46 UTC (rev 2258)
+++ trunk/ChangeLog	2008-02-15 16:32:27 UTC (rev 2259)
@@ -1,3 +1,11 @@
+2008-02-15  Enrico Tröger  <enrico(dot)troeger(at)uvena(dot)de>
+
+ * tagmanager/python.c: Fix parsing bug when there is text after the
+                        end of a multi line comment (closes #1894084).
+ * src/socket.c: Apply patch from Daniel Richard G. to update some
+                 source code comments (thanks).
+
+
 2008-02-13  Enrico Tröger  <enrico(dot)troeger(at)uvena(dot)de>
 
  * src/keybindings.h: Fix broken compilation with GTK < 2.10.

Modified: trunk/src/socket.c
===================================================================
--- trunk/src/socket.c	2008-02-15 16:31:46 UTC (rev 2258)
+++ trunk/src/socket.c	2008-02-15 16:32:27 UTC (rev 2259)
@@ -42,10 +42,10 @@
  * At the moment the commands open, line and column are available.
  *
  * About the socket files on Unix-like systems:
- * Geany creates a socket in /tmp(or any other directory returned by g_get_tmp_dir()) and it creates
+ * Geany creates a socket in /tmp (or any other directory returned by g_get_tmp_dir()) and
  * a symlink in the current configuration to the created socket file. The symlink is named
  * geany_socket.dispnum (dispnum is the number of the active X display).
  * If the socket file in the temporara directory could not be created, Geany creates the socket file
  * directly in the configuration directory as a fallback.
  *
  */
@@ -167,7 +167,7 @@
 	real_path[0] = '\0';
 
 	// read the contents of the symbolic link socket_info.file_name and delete it
-	// readlink should return something like "/tmp/geany_socket.1202396669"
+	// readlink should return something like "/tmp/geany_socket.499602d2"
 	len = readlink(socket_info.file_name, real_path, sizeof(real_path) - 1);
 	if ((gint) len > 0)
 	{
@@ -336,12 +336,12 @@
 		g_get_tmp_dir(), G_DIR_SEPARATOR, g_random_int());
 
 	if (utils_is_file_writeable(real_path) != 0)
-	{	// if real_path is not writable for us, fall back to /home/user/.geany/geany_socket
+	{	// if real_path is not writable for us, fall back to ~/.geany/geany_socket_*_*
 		// instead of creating a symlink and print a warning
 		g_warning("Socket %s could not be written, using %s as fallback.", real_path, path);
 		setptr(real_path, g_strdup(path));
 	}
-	// create a symlink in e.g. /home/user/.geany/geany_socket to /tmp/geany_socket.1202396669
+	// create a symlink in e.g. ~/.geany/geany_socket_hostname__0 to /tmp/geany_socket.499602d2
 	else if (symlink(real_path, path) != 0)
 	{
 		perror("symlink");
@@ -42,10 +42,10 @@
  * a symlink in the current configuration to the created socket file. The symlink is named
- * geany_socket.dispnum (dispnum is the number of the active X display).
- * If the socket file in the temporara directory could not be created, Geany creates the socket file
+ * geany_socket_<hostname>_<displayname> (displayname is the name of the active X display).
+ * If the socket file cannot be created in the temporary directory, Geany creates the socket file
  * directly in the configuration directory as a fallback.
  *


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.



More information about the Commits mailing list